sphinx-notfound-page
====================

Create a custom 404 page with absolute URLs hardcoded.


Installation
------------

::

   pip install sphinx-notfound-page


Configuration
-------------

Add this extension in your ``conf.py`` file as:

.. code-block:: python

   extensions = [
    # ... other extensions here

    'notfound.extension',
   ]


Documentation
-------------

Check out the full documentation at https://sphinx-notfound-page.readthedocs.io/


Thanks
------

**Strongly** based on @ericholscher's solution from https://github.com/rtfd/readthedocs.org/issues/353
